import Video from './video';
import { css, Dimensions, observeResize, parent } from 'uikit-util';

export default {
    mixins: [Video],

    props: {
        width: Number,
        height: Number,
    },

    data: {
        automute: true,
    },

    events: {
        'load loadedmetadata'() {
            this.$emit('resize');
        },
    },

    connected() {
        const parentEl = getPositionedParent(this.$el) || parent(this.$el);
        this.registerObserver(
            observeResize(parentEl, () => {
                this.parentDim = getCoverDimensions(parentEl);
                this.$emit('resize');
            })
        );
    },

    update: {
        read() {
            const { ratio, cover } = Dimensions;
            const { $el, width, height, parentDim } = this;

            let dim = { width, height };

            if (!dim.width || !dim.height) {
                const intrinsic = {
                    width: $el.naturalWidth || $el.videoWidth || $el.clientWidth,
                    height: $el.naturalHeight || $el.videoHeight || $el.clientHeight,
                };

                if (dim.width) {
                    dim = ratio(intrinsic, 'width', dim.width);
                } else if (height) {
                    dim = ratio(intrinsic, 'height', dim.height);
                } else {
                    dim = intrinsic;
                }
            }

            if (!parentDim) {
                return false;
            }

            const coverDim = cover(dim, parentDim);

            if (!coverDim.width || !coverDim.height) {
                return false;
            }

            return coverDim;
        },

        write({ height, width }) {
            css(this.$el, { height, width });
        },

        events: ['resize'],
    },
};

function getCoverDimensions(el) {
    const { offsetHeight, offsetWidth } = el;
    return {
        width: offsetWidth + (offsetWidth % 2 ? 1 : 0),
        height: offsetHeight + (offsetHeight % 2 ? 1 : 0),
    };
}

function getPositionedParent(el) {
    while ((el = parent(el))) {
        if (css(el, 'position') !== 'static') {
            return el;
        }
    }
}
